@@ -23,7 +23,8 @@ use crate::core::effects::Effects;
 use crate::core::eventlog::{Event, EventLogDb, EventReplayer};
 use crate::core::formatting::{printable_styled_string, Pluralize};
 use crate::git::{
-    CategorizedReferenceName, GitRunInfo, MaybeZeroOid, NonZeroOid, Repo, ResolvedReferenceInfo,
+    CategorizedReferenceName, CheckOutCommitOptions, GitRunInfo, MaybeZeroOid, NonZeroOid, Repo,
+    ResolvedReferenceInfo,
 };
 
 use super::execute::check_out_updated_head;
@@ -134,9 +135,9 @@ pub fn hook_post_rewrite(
     let is_spurious_event = rewrite_type == "amend" && repo.is_rebase_underway()?;
     if !is_spurious_event {
         let message_rewritten_commits = Pluralize {
+            determiner: None,
             amount: rewritten_oids.len().try_into()?,
-            singular: "rewritten commit",
-            plural: "rewritten commits",
+            unit: ("rewritten commit", "rewritten commits"),
         }
         .to_string();
         writeln!(
@@ -167,6 +168,7 @@ pub fn hook_post_rewrite(
             &rewritten_oids,
             &previous_head_info,
             skipped_head_updated_oid,
+            &CheckOutCommitOptions::default(),
         )?;
         if exit_code != 0 {
             eyre::bail!("Could not check out your updated `HEAD` commit.");
@@ -235,18 +237,18 @@ fn warn_abandoned(
             if num_abandoned_children > 0 {
                 warning_items.push(
                     Pluralize {
+                        determiner: None,
                         amount: num_abandoned_children.try_into()?,
-                        singular: "commit",
-                        plural: "commits",
+                        unit: ("commit", "commits"),
                     }
                     .to_string(),
                 );
             }
             if num_abandoned_branches > 0 {
                 let abandoned_branch_count = Pluralize {
+                    determiner: None,
                     amount: num_abandoned_branches.try_into()?,
-                    singular: "branch",
-                    plural: "branches",
+                    unit: ("branch", "branches"),
                 }
                 .to_string();
 
@@ -446,7 +448,10 @@ pub fn hook_drop_commit_if_empty(
     writeln!(
         effects.get_output_stream(),
         "Skipped now-empty commit: {}",
-        printable_styled_string(effects.get_glyphs(), head_commit.friendly_describe()?)?
+        printable_styled_string(
+            effects.get_glyphs(),
+            head_commit.friendly_describe(effects.get_glyphs())?
+        )?
     )?;
     repo.set_head(only_parent_oid)?;
 
@@ -482,7 +487,10 @@ pub fn hook_skip_upstream_applied_commit(
     writeln!(
         effects.get_output_stream(),
         "Skipping commit (was already applied upstream): {}",
-        printable_styled_string(effects.get_glyphs(), commit.friendly_describe()?)?
+        printable_styled_string(
+            effects.get_glyphs(),
+            commit.friendly_describe(effects.get_glyphs())?
+        )?
     )?;
 
     if let Some(orig_head_reference) = repo.find_reference(OsStr::new("ORIG_HEAD"))? {
